[Unit]
Description=CFEngine Execution Scheduler
After=syslog.target
ConditionPathExists={{{vars.sys.bindir}}}/cf-execd
PartOf=cfengine3.service

[Service]
Type=simple
ExecStart={{{vars.sys.bindir}}}/cf-execd --no-fork --verbose
Restart=always
RestartSec=10
KillMode=process

[Install]
WantedBy=multi-user.target
WantedBy=cfengine3.service
